@@ -18,6 +18,7 @@ class WorkspaceRun:
                                                   env_value[LcConst.BACK_END_API_PORT],
                                                   env_value[LcConst.BACK_END_API_URI])
         self.code_path = None
+        self.custom_args = None
 
     def exec_code(self):
         parser = argparse.ArgumentParser()
@@ -25,11 +26,13 @@ class WorkspaceRun:
         parser.add_argument('--codePath', default=None)
         parser.add_argument('--stopFlag', default=False)
         parser.add_argument('--stopTimeout', default=60)
+        parser.add_argument('--args', default='')
 
         args, unknown = parser.parse_known_args()
         args_dict = vars(args)
 
         self.code_path = args_dict['codePath']
+        self.custom_args = '--' + args_dict['args'].replace(',', " --").replace(':', '=')
         self.workspace_run_log.workspace_run_id = args_dict['workspaceRunId']
         self.workspace_run_log.stop_flag = args_dict['stopFlag']
         self.workspace_run_log.stop_timeout = args_dict['stopTimeout']
@@ -38,10 +41,8 @@ class WorkspaceRun:
             raise Exception("codePath cannot be none")
 
         try:
-            subprocess.run("python3 -u %s > "
-                           "/tmp/output_%s.log 2>&1"
-                           % (self.code_path + ' ' + ' '.join(unknown),
-                              self.workspace_run_log.workspace_run_id),
+            subprocess.run("python3 -u %s %s > /tmp/output_%s.log 2>&1" %
+                           (self.code_path, self.custom_args, self.workspace_run_log.workspace_run_id),
                            shell=True, encoding='UTF-8').check_returncode()
             self.workspace_run_log.is_success = True
         except subprocess.CalledProcessError:
