@@ -2,9 +2,8 @@ from collections.abc import Mapping
 from csv import DictReader
 import json
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
-from Accuinsight.modeler.core.LcConst.LcConst import RUN_RESULT_PATH, \
-    RUN_MODEL_VISUAL_CSV_PATH, RUN_MODEL_VISUAL_JSON_PATH, \
-    RUN_MODEL_JSON_PATH, RUN_MODEL_SHAP_JSON_PATH, SELECTED_METRICS
+from Accuinsight.modeler.core.LcConst.LcConst import RUN_RESULT_PATH, RUN_MODEL_VISUAL_CSV_PATH, \
+    RUN_MODEL_VISUAL_JSON_PATH, RUN_MODEL_JSON_PATH, SELECTED_METRICS
 from Accuinsight.modeler.protos.life_cycle_pb2 import LcMetric, LcParam
 from Accuinsight.modeler.core.Run.ParseRun import Parse_Helper
 
@@ -29,6 +28,7 @@ def load_parameter(run_meta):
 
     return param_json_data
 
+
 def load_visual_json(run_meta):
     run_result_path = run_meta[RUN_RESULT_PATH]
     json_path = run_result_path[RUN_MODEL_VISUAL_JSON_PATH]
