@@ -6,6 +6,7 @@ from sklearn.metrics import confusion_matrix, f1_score, precision_score, recall_
 from Accuinsight.modeler.core import get
 from Accuinsight.modeler.core.func_for_visual import cal_confusion, cal_auc, multi_roc, multi_pr
 
+
 def y_test_reshape(y_test):
     # dataframe/series형 np.array로 형 변환
     if 'pandas' in str(type(y_test)):
@@ -23,11 +24,12 @@ def y_test_reshape(y_test):
             y_test = np.array([np.where(y_test[i]==np.max(y_test[i]))[0].tolist() for i in range(len(y_test))]).flatten()
         else:
             y_test = y_test.flatten()
-    return(y_test)
+    return y_test
+
 
 def y_test_to_categorical(y_test):
     try:
-        n_classes = len(np.unique(y_test, axis = 0))
+        n_classes = len(np.unique(y_test, axis=0))
     except:
         n_classes = len(np.unique(y_test))
         
@@ -45,7 +47,8 @@ def y_test_to_categorical(y_test):
     elif y_test.ndim == 2 and y_test.shape[1] == n_classes:  # y_test: categorical
         y_test_cat = y_test
 
-    return(y_test_cat)
+    return y_test_cat
+
 
 def y_pred_reshape(model, X_test):
     prob = model.predict(X_test)
@@ -60,7 +63,8 @@ def y_pred_reshape(model, X_test):
         else:
             y_prob = prob
             y_pred = np.array([np.where(y_prob[i]==np.max(y_prob[i]))[0].tolist() for i in range(len(y_prob))]).flatten()
-    return(y_pred)
+    return y_pred
+
 
 def y_pred_to_categorical(model, X_test, y_test):
     try:
@@ -70,6 +74,7 @@ def y_pred_to_categorical(model, X_test, y_test):
         
     prob = model.predict(X_test)
     enc = OneHotEncoder(categories = 'auto')
+    y_pred_cat = None
 
     if prob.ndim == 1:
         prob = np.array([1 if i>=0.5 else 0 for i in prob])
@@ -88,9 +93,11 @@ def y_pred_to_categorical(model, X_test, y_test):
             for i in range(y_pred_cat.shape[0]):
                 y_pred_cat[i][np.where(prob[i] == np.max(prob[i]))[0]] = 1
 
-    return(y_pred_cat)
+    return y_pred_cat
+
 
 def y_score_proba(model, X_test, y_test):
+    y_score = None
     if get.model_type(model) == 'SVC' and 'probability=False' in str(model):
         if len(model.classes_) == 2:
             d = model.decision_function(X_test)
@@ -106,7 +113,6 @@ def y_score_proba(model, X_test, y_test):
             y_score = np.c_[prob, 1-prob]
         else:
             warnings.warn('label의 갯수가 3 이상인 경우, LinearSVC에서 "predict_proba"를 제공하지 않아 metric 계산이 불가능합니다. 자세한 사항은 사용자 매뉴얼을 참조하십시오.')
-            y_score = None
             
     elif 'keras' in get.model_type(model):
 #       prob = model.predict_proba(X_test)   -- predict_proba() is deprecated.
@@ -124,16 +130,11 @@ def y_score_proba(model, X_test, y_test):
             y_score = model.predict(X_test)
             if y_score.ndim == 1:
                 y_score = np.c_[y_score, 1-y_score]
-    return(y_score)
+    return y_score
+
 
 # (DL & ML) & Classification
 def roc_pr_curve(model, X_test, y_test, *args):
-    
-    try:
-        n_classes = len(np.unique(y_test, axis = 0))
-    except:
-        n_classes = len(np.unique(y_test))
-    
     # y_test (dim=2/dim=1, 두 가지 경우 존재)
     # y_test는 categorical var. 변경 필요
     y_test = y_test_reshape(y_test)
@@ -176,13 +177,13 @@ def roc_pr_curve(model, X_test, y_test, *args):
     res_dict['confusion_matrix'] = dict(zip(label_list, confusion_matrix(y_test, y_pred, labels = label_list).tolist()))
     res_dict['chart'] = {'AUC': res_roc['auc']['micro'],
                          'Precision': res_pr['auc']['micro'],
-                         'Recall': recall_score(y_test, y_pred, average = 'micro'),
-                         'F1-score': f1_score(y_test, y_pred, average = 'micro')}
-    return(res_dict)
+                         'Recall': recall_score(y_test, y_pred, average='micro'),
+                         'F1-score': f1_score(y_test, y_pred, average='micro')}
+    return res_dict
+
 
 # (DL & ML) & Regression
 def get_true_y(y_test):
-    
     # reshape (dim2 -> dim1)
     if len(y_test.shape) == 2:
         true_y = y_test.reshape(1,-1)[0].tolist()
@@ -190,8 +191,9 @@ def get_true_y(y_test):
         true_y = y_test
     else:
         true_y = y_test.tolist()
-    return(true_y)
-        
+    return true_y
+
+
 def get_visual_info_regressor(model, X_test):
     preds = model.predict(X_test)
 
@@ -203,9 +205,9 @@ def get_visual_info_regressor(model, X_test):
     try:
         if len(str(preds[0]).split('.')[1]) >= 5:
             preds = np.round(preds, 4)
-            preds = list(map(float, np.array(preds, dtype = str).tolist()))
+            preds = list(map(float, np.array(preds, dtype=str).tolist()))
         else:
-            preds = list(map(float, np.array(preds, dtype = str).tolist()))
+            preds = list(map(float, np.array(preds, dtype=str).tolist()))
     except TypeError:
         pass
-    return(preds)
+    return preds
